# plottwist-bootstrap
============================================================

Repository that contains source code for Plot Twist Bootstrap


.. image:: https://travis-ci.com/Plot-Twist-Short-Film/plottwist-bootstrap.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/Plot-Twist-Short-Film/plottwist-bootstrap

.. image:: https://coveralls.io/repos/github/Plot-Twist-Short-Film/plottwist-bootstrap/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/Plot-Twist-Short-Film/plottwist-bootstrap?branch=master

.. image:: https://img.shields.io/github/license/Plot-Twist-Short-Film/plottwist-bootstrap
    :target: https://github.com/Plot-Twist-Short-Film/plottwist-bootstrap/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/plottwist-bootstrap?branch=master&kill_cache=1
    :target: https://pypi.org/project/plottwist-bootstrap/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/